/* FILE: callbacks.c
 * DESCRIPTION: Exemple GTK2+ pour capter les touches du clavier.
 * AUTHOR: Guillaume Riviere (C) 2017
 */

#include <stdio.h>   /* sprintf */
#include <string.h>  /* strcpy */

#include <gdk/gdkkeysyms-compat.h> /* Evenements clavier/souris/... */
#include "callbacks.h"

extern GtkBuilder *builder;

void on_window1_destroy (GtkObject *object, gpointer user_data) {
  printf("Fermeture de la fenetre.\n");
  gtk_main_quit();
}

void on_window1_realize (GtkObject *object, gpointer user_data) {
  GtkWidget *window1 = GTK_WIDGET (gtk_builder_get_object (builder, "window1"));
  
  /* Brancher l'ecoute les signaux du clavier */
  gtk_widget_add_events (window1, GDK_KEY_PRESS_MASK) ;

  /* Connecter la fonction au signaux du clavier */
  g_signal_connect (window1, "key_press_event", G_CALLBACK (key_press_callback), NULL);
}

gboolean key_press_callback (GtkWidget *widget, GdkEventKey *event) {
  gboolean res = FALSE ;
  char key[32] = "" ;
  GtkLabel *label_message = GTK_LABEL (gtk_builder_get_object (builder, "label_message"));

  switch (event->keyval) { /* Voir definitions dans le fichier gdk/gdkkeysyms-compat.h */

  case GDK_Up :
    strcpy (key, "Up") ;
    res = TRUE ;
    break ;

  case GDK_Down :
    strcpy (key, "Down") ;
    res = TRUE ;
    break ;

  case GDK_Left :
    strcpy (key, "Left") ;
    res = TRUE ;
    break ;

  case GDK_Right :
    strcpy (key, "Right") ;
    res = TRUE ;
    break ;

  case GDK_Q :
  case GDK_q :
    if (event->state & GDK_CONTROL_MASK) {
      strcpy (key, "ctrl + Q") ;
      printf("Fermeture de la fenetre.\n");
      gtk_main_quit();
    }
    else {
      strcpy (key, "Q") ;
    }
    res = TRUE ;
    break ;

  case GDK_A :
  case GDK_a :
    strcpy (key, "A") ;
    res = TRUE ;
    break ;

  case GDK_F1 :
    strcpy (key, "F1") ;
    res = TRUE ;
    break ;

  case GDK_space :
    strcpy (key, "space") ;
    res = TRUE ;
    break ;

  case GDK_Escape :
    strcpy (key, "Espace") ;
    res = TRUE ;
    break ;

  case GDK_1 :
    strcpy (key, "1") ;
    res = TRUE ;
    break ;
    
  default :
    strcpy  (key, "Other...") ;
    break ;
  }

  printf ("Touche : %s\n", key) ;
  gtk_label_set_text (label_message, key) ;
  
  return res;
}
